netapp_ontap.models.aggregate_inactive_data_reporting API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_inactive_data_reporting`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateInactiveDataReportingSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateInactiveDataReporting object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET PATCH`

    Specifes whether or not inactive data reporting is enabled on the aggregate.

  `start_time GET`

    Timestamp at which inactive data reporting was enabled on the aggregate.

    Example: 2019-12-12T16:00:00.000+0000